EffectError

Enum EffectError 

pub enum EffectError {
    ZeroLeds,
    TooManyLeds {
        requested: usize,
        max: usize,
    },
    ZeroStep,
    ZeroDuty,
    BufferTooSmall {
        required: usize,
        actual: usize,
    },
    TooManySections {
        requested: usize,
        max: usize,
    },
}
Error type for effect configuration and operations.

Variants



ZeroLeds

The number of LEDs must be greater than 0.



TooManyLeds

The number of LEDs exceeds the maximum supported (256).

Fields

requested: usize

Number of LEDs requested.

max: usize

Maximum supported.



ZeroStep

Speed/step must be greater than 0.



ZeroDuty

On and off durations must both be greater than 0.



BufferTooSmall

Buffer is too small for the configured number of LEDs.

Fields

required: usize

Number of LEDs configured.

actual: usize

Actual buffer size provided.



TooManySections

Too many sections for the effect.

Fields

requested: usize

Number of sections requested.

max: usize

Maximum supported.