pub enum EffectError {
ZeroLeds,
TooManyLeds {
requested: usize,
max: usize,
},
ZeroStep,
ZeroDuty,
BufferTooSmall {
required: usize,
actual: usize,
},
TooManySections {
requested: usize,
max: usize,
},
}Expand description
Error type for effect configuration and operations.
Variants
ZeroLeds
The number of LEDs must be greater than 0.
TooManyLeds
The number of LEDs exceeds the maximum supported (256).
ZeroStep
Speed/step must be greater than 0.
ZeroDuty
On and off durations must both be greater than 0.
BufferTooSmall
Buffer is too small for the configured number of LEDs.
TooManySections
Too many sections for the effect.